Index: third_party/WebKit/public/web/WebRemoteFrame.h |
diff --git a/third_party/WebKit/public/web/WebRemoteFrame.h b/third_party/WebKit/public/web/WebRemoteFrame.h |
index e431c64360b53fa2e2485a8b1885748455e402aa..5ff2aaa40740bb004e01096566702b972a294c75 100644 |
--- a/third_party/WebKit/public/web/WebRemoteFrame.h |
+++ b/third_party/WebKit/public/web/WebRemoteFrame.h |
@@ -23,9 +23,9 @@ public: |
// insertion order, so the local child version takes a previous sibling to |
// ensure that it is inserted into the correct location in the list of |
// children. |
- virtual WebLocalFrame* createLocalChild(WebTreeScopeType, const WebString& name, WebSandboxFlags, WebFrameClient*, WebFrame* previousSibling, const WebFrameOwnerProperties&) = 0; |
+ virtual WebLocalFrame* createLocalChild(WebTreeScopeType, const WebString& name, const WebString& uniqueName, WebSandboxFlags, WebFrameClient*, WebFrame* previousSibling, const WebFrameOwnerProperties&) = 0; |
- virtual WebRemoteFrame* createRemoteChild(WebTreeScopeType, const WebString& name, WebSandboxFlags, WebRemoteFrameClient*) = 0; |
+ virtual WebRemoteFrame* createRemoteChild(WebTreeScopeType, const WebString& name, const WebString& uniqueName, WebSandboxFlags, WebRemoteFrameClient*) = 0; |
// Transfer initial drawing parameters from a local frame. |
virtual void initializeFromFrame(WebLocalFrame*) const = 0; |
@@ -36,8 +36,8 @@ public: |
// Set sandbox flags replicated from another process. |
virtual void setReplicatedSandboxFlags(WebSandboxFlags) const = 0; |
- // Set frame name replicated from another process. |
- virtual void setReplicatedName(const WebString&) const = 0; |
+ // Set frame |name| and |uniqueName| replicated from another process. |
+ virtual void setReplicatedName(const WebString& name, const WebString& uniqueName) const = 0; |
// Set frame enforcement of strict mixed content checking replicated from another process. |
virtual void setReplicatedShouldEnforceStrictMixedContentChecking(bool) const = 0; |